---
name: New issue
about: Open a new issue with detailed description

---

Description 
=========== 
_provide a complete description of the work to be done_

Modules to be created 
--------------------- 
_a list of modules that should be created_

Modules to be modified
---------------------- 
_a list of modules that are expected to be modified_

Tests to be created/updated 
--------------------------- 
_a list of tests to be created/updated (unit-tests and hardware test scripts)_

Documentation to be updated 
--------------------------- 
_a list of documents that need updates (like CHANGELOG.md, Sphinx docs)_

Hardware 
-------- 
_a list of hardware if needed for testing; must be available!_

